# MetaBasesBody

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name for the new base | 
**workspace_id** | **str** | The workspace where the base will be created | 
**tables** | [**list[TableConfig]**](TableConfig.md) | List of tables to create with the base | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

